% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/parMCMC.R
\name{parMCMC}
\alias{parMCMC}
\title{Function to run MCMC chain}
\usage{
parMCMC(Data.list, X.list, norm.mat, index.seq, index.array, iteration, chunks,
  seed = 15213)
}
\arguments{
\item{Data.list}{is a list of K elements, where K is the number of studies, 
each element is a microarray or RNAseq expression matrix with 
G rows and N columns, where G is number of matched genes and N 
is the sample size.}

\item{X.list}{is a list of K elements, each element includes is 
a phenotypic condition of the corresponding samples, with case=1, control=0.}

\item{norm.mat}{is a matrix of normalization factors, with K columns and G rows.}

\item{index.seq}{index for RNA-seq studies}

\item{index.array}{index for microarray studies}

\item{iteration}{is the number of MCMC chains wish to run}

\item{chunks}{is the number of cpu's called}

\item{seed}{is a initial seed for random number generator.}
}
\value{
a list of MCMC output matrices for three key parameters of
interest: the DE indicator "Delta", the study-specific effect size
"ES", and the grand mean effect size "Lambda". For details, please
refer to the paper "A joint Bayesian modeling for integrating 
microarray and RNA-seq transcriptomic data"
}
\description{
Function to run parallel MCMC chain 
The \code{parMCMC} is a function to run the MCMC chain
}
\examples{
\dontrun{
data(SimData)
G <- nrow(Data.list[[1]])
adjust.seq1 <-  adjust.seq2 <- adjust.array1 <-  adjust.array2 <- rep(0,G)
## For simulation, we already know the normalization factor:
adjust.array1[1:200] <- adjust.array2[1:200] <- -0.25
adjust.array1[201:400] <- adjust.array2[201:400] <- 0.25
norm.mat <- cbind(adjust.seq1,adjust.seq2,adjust.array1,
adjust.array2)
index.seq <- 1:2
index.array <- 3:4
iteration <- 2000
MCMC.out <- parMCMC(Data.list, X.list, norm.mat, index.seq,
                    index.array, iteration, chunks=2)
}
}
